@@ -81,15 +81,19 @@ import com.openexchange.mail.mime.MimeMailException;
 import com.openexchange.mail.mime.MimeMailExceptionCode;
 import com.openexchange.mail.mime.MimeSessionPropertyNames;
 import com.openexchange.mailaccount.MailAccount;
+import com.openexchange.net.ssl.SSLSocketFactoryProvider;
+import com.openexchange.net.ssl.config.SSLConfigurationService;
+import com.openexchange.net.ssl.exception.SSLExceptionCode;
 import com.openexchange.pop3.POP3ExceptionCode;
 import com.openexchange.pop3.POP3Provider;
 import com.openexchange.pop3.config.IPOP3Properties;
 import com.openexchange.pop3.config.POP3Config;
 import com.openexchange.pop3.config.POP3Properties;
 import com.openexchange.pop3.config.POP3SessionProperties;
+import com.openexchange.pop3.services.POP3ServiceRegistry;
 import com.openexchange.pop3.util.POP3CapabilityCache;
+import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.session.Session;
-import com.openexchange.tools.ssl.TrustAllSSLSocketFactory;
 import com.sun.mail.pop3.POP3Folder;
 import com.sun.mail.pop3.POP3Prober;
 import com.sun.mail.pop3.POP3Store;
@@ -304,26 +308,37 @@ public final class POP3StoreConnector {
              * With JavaMail v1.4.3 the JavaMail POP3 provider supports to start in plain text mode and
              * then switching the connection into TLS mode using the STLS command.
              */
-            final String sPort = String.valueOf(port);
-            final String socketFactoryClass = TrustAllSSLSocketFactory.class.getName();
+            String sPort = String.valueOf(port);
+            SSLSocketFactoryProvider factoryProvider = POP3ServiceRegistry.getServiceRegistry().getService(SSLSocketFactoryProvider.class);
+            String socketFactoryClass = factoryProvider.getDefault().getClass().getName();
+            String protocols = pop3Config.getPOP3Properties().getSSLProtocols();
+            String cipherSuites = pop3Config.getPOP3Properties().getSSLCipherSuites();
+            SSLConfigurationService sslConfigService = POP3ServiceRegistry.getServiceRegistry().getService(SSLConfigurationService.class);
             if (pop3Config.isSecure()) {
                 pop3Props.put("mail.pop3.socketFactory.class", socketFactoryClass);
                 pop3Props.put("mail.pop3.socketFactory.port", sPort);
                 pop3Props.put("mail.pop3.socketFactory.fallback", "false");
-                /*
-                 * Needed for JavaMail >= 1.4
-                 */
-                // Security.setProperty("ssl.SocketFactory.provider", TrustAllSSLSocketFactory.class.getName());
                 /*
                  * Specify SSL protocols
                  */
-                pop3Props.put("mail.pop3.ssl.protocols", pop3Config.getPOP3Properties().getSSLProtocols());
+                if (Strings.isNotEmpty(protocols)) {
+                    pop3Props.put("mail.pop3.ssl.protocols", protocols);
+                } else {
+                    if (null == sslConfigService) {
+                        throw ServiceExceptionCode.absentService(SSLConfigurationService.class);
+                    }
+                    pop3Props.put("mail.pop3.ssl.protocols", Strings.toWhitespaceSeparatedList(sslConfigService.getSupportedProtocols()));
+                }
                 /*
                  * Specify SSL cipher suites
                  */
-                final String cipherSuites = pop3Config.getPOP3Properties().getSSLCipherSuites();
-                if (false == Strings.isEmpty(cipherSuites)) {
+                if (Strings.isNotEmpty(cipherSuites)) {
                     pop3Props.put("mail.pop3.ssl.ciphersuites", cipherSuites);
+                } else {
+                    if (null == sslConfigService) {
+                        throw ServiceExceptionCode.absentService(SSLConfigurationService.class);
+                    }
+                    pop3Props.put("mail.pop3.ssl.ciphersuites", Strings.toWhitespaceSeparatedList(sslConfigService.getSupportedCipherSuites()));
                 }
             } else {
                 /*
@@ -344,13 +359,24 @@ public final class POP3StoreConnector {
                 /*
                  * Specify SSL protocols
                  */
-                pop3Props.put("mail.pop3.ssl.protocols", pop3Config.getPOP3Properties().getSSLProtocols());
+                if (Strings.isNotEmpty(protocols)) {
+                    pop3Props.put("mail.pop3.ssl.protocols", protocols);
+                } else {
+                    if (null == sslConfigService) {
+                        throw ServiceExceptionCode.absentService(SSLConfigurationService.class);
+                    }
+                    pop3Props.put("mail.pop3.ssl.protocols", Strings.toWhitespaceSeparatedList(sslConfigService.getSupportedProtocols()));
+                }
                 /*
                  * Specify SSL cipher suites
                  */
-                final String cipherSuites = pop3Config.getPOP3Properties().getSSLCipherSuites();
-                if (false == Strings.isEmpty(cipherSuites)) {
+                if (Strings.isNotEmpty(cipherSuites)) {
                     pop3Props.put("mail.pop3.ssl.ciphersuites", cipherSuites);
+                } else {
+                    if (null == sslConfigService) {
+                        throw ServiceExceptionCode.absentService(SSLConfigurationService.class);
+                    }
+                    pop3Props.put("mail.pop3.ssl.ciphersuites", Strings.toWhitespaceSeparatedList(sslConfigService.getSupportedCipherSuites()));
                 }
                 // pop3Props.put("mail.pop3.ssl.enable", "true");
                 /*
@@ -428,6 +454,10 @@ public final class POP3StoreConnector {
                 }
                 throw e;
             } catch (final MessagingException e) {
+                if (MimeMailException.isSSLHandshakeException(e)) {
+                    throw SSLExceptionCode.UNTRUSTED_CERTIFICATE.create(e.getCause(), server);
+                }
+
                 final Exception nested = e.getNextException();
                 if (nested != null) {
                     if (nested instanceof IOException) {
