@@ -63,6 +63,9 @@ import com.openexchange.groupware.settings.PreferencesItemService;
 import com.openexchange.log.audit.AuditLogService;
 import com.openexchange.mail.api.MailProvider;
 import com.openexchange.mailaccount.MailAccountStorageService;
+import com.openexchange.net.ssl.SSLSocketFactoryProvider;
+import com.openexchange.net.ssl.config.SSLConfigurationService;
+import com.openexchange.net.ssl.config.UserAwareSSLConfigurationService;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.osgi.ServiceRegistry;
 import com.openexchange.pop3.Enabled;
@@ -97,7 +100,8 @@ public final class POP3Activator extends HousekeepingActivator {
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] {
             ConfigurationService.class, CacheService.class, UserService.class, MailAccountStorageService.class,
-            ContextService.class, TimerService.class, ConfigViewFactory.class, CapabilityService.class, ThreadPoolService.class, CharsetService.class
+            ContextService.class, TimerService.class, ConfigViewFactory.class, CapabilityService.class, SSLSocketFactoryProvider.class,
+            SSLConfigurationService.class, UserAwareSSLConfigurationService.class, ThreadPoolService.class, CharsetService.class
         };
     }
 
@@ -149,8 +153,8 @@ public final class POP3Activator extends HousekeepingActivator {
              * Service tracker for possible POP3 storage provider
              */
             track(POP3StorageProvider.class, customizer);
-            track(SessiondService.class);
-            trackService(AuditLogService.class);
+            track(SessiondService.class, new RegistryCustomizingServiceTrackerCustomizer<SessiondService>(SessiondService.class, context));
+            track(AuditLogService.class, new RegistryCustomizingServiceTrackerCustomizer<AuditLogService>(AuditLogService.class, context));
             openTrackers();
             /*
              * Register
